//Importing required modules from d3
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  max,
  axisLeft,
  axisBottom,
  area,
  curveBasis,
  format
} from 'd3';

const svg = select('svg');

// Add width and height of the chart
const width = +svg.attr('width');
const height = +svg.attr('height');
const xAxisTickFormat = number =>
    format('.3s')(number)

const render = data => {
  const title = 'GDP in India from 2009-2022';//adding title to the graph
  
  // x axis label
  const xValue = d => d.Year;
  const xAxisLabel = 'years';
  
  //Y-axis label
  const yValue = d => d.IndiaGDP;
  const yAxisLabel = 'IndiaGDP';
  
  //padding
  const margin = { top: 20, right: 40, bottom: 88, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  // Adding scaleTime function
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  // Adding scaleLinear function 
  const yScale = scaleLinear()
    .domain([0, max(data, yValue)])
    .range([innerHeight, 0])
    .nice();
  
  // Locating the graph
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  // Add attributes of x-axis
  const xAxis = axisBottom(xScale)
    .ticks(10)
    .tickSize(-innerHeight)
    .tickPadding(10);
 
  // Format y-axis tick
  const yAxisTickFormat = number =>
    format('.1s')(number)
      .replace('G', 'B');
  
    // Add attributes of y-axis
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10)
    .tickFormat(yAxisTickFormat);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  //attributes of y-axis
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -60)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
xAxisG.select('.domain').remove();
  
  //attributes of x-axis
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  // Controlling the area
  const areaGenerator = area()
    .x(d => xScale(xValue(d)))
    .y(innerHeight)
    .y1(d => yScale(yValue(d)))
    .curve(curveBasis);
  
  // Add additributes to path
  g.append('path')
      .attr('class', 'line-path')
      .attr('d', areaGenerator(data));
  
  // Control title
  svg.append('text')
      .attr('class', 'title')
      .attr('x', width / 2)
      .attr('y', 45)
      .text(title);
};

csv('https://gist.githubusercontent.com/prachow/0d24f040eda7e30ac7e4793def0d6bce/raw/99f1770f9f58d90401948288fa429a9b33671188/gdp.csv')
  .then(data => {
    data.forEach(d => {
      d.IndiaGDP = +d.IndiaGDP;
      d.Year = +d.Year;
    });
    render(data);
  console.log(data);
  });